<?php
// No direct file access
!defined('ABSPATH') AND exit;

function bee_get_abandoned_data($date='') {
	if ($date == '' || $date == 'today') {
		$date = date("Y-m-d");
		global $wpdb;
		
		$tableName = $wpdb->prefix . 'bee_abandoned';
		$sql = $wpdb->prepare(
		    "SELECT * FROM $tableName WHERE DATE(last_modified_date) = %s",
		    $date
		);
		$results = $wpdb->get_results($sql);
	}
	elseif ($date == 'yesterday') {
		$date = date("Y-m-d", strtotime("yesterday"));
		global $wpdb;
		
		$tableName = $wpdb->prefix . 'bee_abandoned';
		$sql = $wpdb->prepare(
		    "SELECT * FROM $tableName WHERE DATE(last_modified_date) = %s",
		    $date
		);
		$results = $wpdb->get_results($sql);
	}
	elseif ($date == 'week') {
		$today = date("Y-m-d");
		$startdate = date("Y-m-d", strtotime('monday this week', strtotime($today)));
		$enddate = date("Y-m-d", strtotime('sunday this week', strtotime($today)));
		global $wpdb;
		
		$tableName = $wpdb->prefix . 'bee_abandoned';
		$sql = $wpdb->prepare(
		    "SELECT * FROM $tableName WHERE DATE(last_modified_date) BETWEEN %s AND %s",
		    $startdate,
		    $enddate
		);
		$results = $wpdb->get_results($sql);

	}
	elseif ($date == 'month') {
		$startdate = date("Y-m-01");
		$enddate = date("Y-m-t");
		global $wpdb;
		
		$tableName = $wpdb->prefix . 'bee_abandoned';
		$sql = $wpdb->prepare(
		    "SELECT * FROM $tableName WHERE DATE(last_modified_date) BETWEEN %s AND %s",
		    $startdate,
		    $enddate
		);
		$results = $wpdb->get_results($sql);
	}
	else {
		$results = '';
	}


	if ( !empty($results) ) {
		$emailItemsArray = [];

		foreach ($results as $item) {
		    $email = $item->email;

		    if (!isset($emailItemsArray[$email])) {
		        $emailItemsArray[$email] = [];
		    }

		    $emailItemsArray[$email][] = $item->items;
		}

		return $emailItemsArray;
	}
}

/**
 * Add amin menu
 */
function bee_aband_admin_menu() {

	$menu_url = menu_page_url( 'bee-plugins', false );

	if ( ! $menu_url ) {
        add_menu_page(
            'BeePlugins',
            'BeePlugins',
            'manage_options',
            'bee-plugins',
            'bee_aband_page',
            BeeAban_URL .'assets/images/bee-icon.png',
            50
        );
        add_submenu_page(
	        'bee-plugins',
	        'Bee Abandoned',
	        'Bee Abandoned',
	        'manage_options',
	        'bee-plugins',
	        'bee_aband_page',
	    );
        add_submenu_page(
            'bee-plugins',
            'BeePlugins Addons',
            'Addons',
            'manage_options',
            'bee-plugins-addons',
            'bee_plugins_addons',
        );
    }
    else {
    	add_submenu_page(
	        'bee-plugins',
	        'Bee Abandoned',
	        'Bee Abandoned',
	        'manage_options',
	        'bee-aband-page',
	        'bee_aband_page',
	    );
    }
}
add_action('admin_menu', 'bee_aband_admin_menu');


/**
 * List all abandoned
 */
if ( !function_exists( 'bee_aband_page' ) ) {
	function bee_aband_page(){
		if ( is_admin() ) {
			if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['aband_filter'])) {
				$date = $_POST['aband_filter'];
			}
			else {
				$date = '';
			}
			$table_data = bee_get_abandoned_data($date);
			?>
	        <div class="clear"></div>
	        <div class="bee-aband-wrapper">
                <h2><?php echo __('Bee Abandoned Shopping Cart', 'bee_abandoned'); ?></h2>
            </div>

            <div class="clear"></div>
            <div class="bee-aband-wrapper">
            	<div class="bee-aband-panel">
                    <div class="section date-range-picker">
                    	<form method="POST" action="">
                    		<label>Filter by Date: </label>
                    		<select name="aband_filter">
                    			<option value="today">Today</option>
                    			<option value="yesterday" <?php echo ( $date == 'yesterday') ? 'selected' : '' ?>>Yesterday</option>
                    			<option value="week" <?php echo ( $date == 'week') ? 'selected' : '' ?>>This Week</option>
                    			<option value="month" <?php echo ( $date == 'month') ? 'selected' : '' ?>>This month</option>
                    		</select>
                    		<input type="submit" name="filter_submit" value="Filter">
                    	</form>
                    </div>
                </div>
            </div>

            <div class="clear"></div>
            <div class="bee-aband-wrapper">
            	<div class="bee-aband-panel">
                    <div class="section aband-table">
                    	<?php
                    	if ( !empty($table_data) ) {
                    		?>
                    		<table class="bee-aband-table">
                    			<thead>
                    				<tr>
                    					<th>Email</th>
                    					<th>Products</th>
                    					<th>#</th>
                    				</tr>
                    			</thead>
                    			<tbody>
                    				<?php
                    				foreach ($table_data as $email => $product_ids) {
                    					echo '<tr>';
                    					echo '<td>'. $email .'</td>';
                    					echo '<td>';
                    					foreach ( $product_ids as $product_id ) {
                    						echo get_the_title($product_id) . ', ';
                    					}
                    					echo '</td>';
                    					echo '<td><button class="send_aband_email" data-email="'.$email.'" data-products="'.implode(', ', $product_ids).'">Send Email</button></td>';
                    					echo '</tr>';
                    				}
                    				?>
                    			</tbody>
                    		</table>
                    		<?php
                    	}
                    	else {
                    		echo '<p>No record Found!</p>';
                    	}
                    	?>
                    </div>
                </div>
            </div>

	        
	        <?php
		}
	}
}