<?php
// No direct file access
!defined('ABSPATH') AND exit;

/**
 * loader class for BeeAbandoned
 */
class BeeAbandoned {
	function __construct(){
		add_action( 'init', array( $this, 'bee_set_abandoned_cookie' ) );

		if ( !isset($_COOKIE['bee_aban_email']) ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'bee_add_popup_script') );
			add_action( 'wp_footer', array( $this, 'bee_load_aban_popup') );
			
		}
		add_action( 'woocommerce_add_to_cart', array( $this, 'bee_aban_add_to_cart_update_cookie' ), 10, 2);
		add_action( 'woocommerce_thankyou', array( $this, 'bee_remove_product_abandon'));
	}

	// check abandoned
	public function bee_is_abandoned()
	{
		return ;
	}

	// set cookie for user data
	public function bee_set_abandoned_cookie() {

		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			$user_email = $current_user->user_email;
			
			if ( !isset($_COOKIE['bee_aban_email']) ) {
				$expiration_time = time() + (7 * 24 * 60 * 60);
				setcookie( 'bee_aban_email', $user_email, $expiration_time, COOKIEPATH, COOKIE_DOMAIN);
			}
		}
		
	}

	// load popup js
	public function bee_add_popup_script() {
		wp_register_script( 'exitintent', BeeAban_URL . '/assets/js/exitintent.js', array('jquery'), time(), true);
		wp_register_script( 'bee-aban-popup', BeeAban_URL . '/assets/js/bee-aban-popup.js', array('jquery', 'exitintent'), time(), true);
		wp_enqueue_script('bee-aban-popup');
		wp_enqueue_style( 'bee-aban-popup', BeeAban_URL . '/assets/css/bee-aban-popup.css');

		$loc_data = array(
		    'ajax_url' => admin_url('admin-ajax.php'),
		    'nonce'    => wp_create_nonce('beeaban'),
		);

		wp_localize_script('bee-aban-popup', 'beeabandon', $loc_data);
	}

	// load popup in footer
	public function bee_load_aban_popup(){
		$popup_title 	= 'Wait! Before You Go...';
		$popup_desc 	= 'Subscribe to our newsletter for updates on new arrivals, special offers, and insider access. Join our community today!';
		?>
		<button onclick="openPopup()">Open Popup</button>
		<!-- Popup Content -->
		<div id="beeabanpopup" class="popup">
		    <span class="close-btn" onclick="closePopup()">&times;</span>
		    <h2><?php echo $popup_title ?></h2>
		    <p><?php echo $popup_desc ?></p>
		    <form id="beeabanform" action="#" method="post">
		        <input type="email" id="email" name="email" required placeholder="Email">
		        <br>
		        <input type="submit" id="beeabansubmit" value="Subscribe">
		    </form>
		</div>

		<!-- Overlay -->
		<div id="beeabanoverlay" class="overlay" onclick="closePopup()"></div>
		<?php
	}

	// set abandoned
	public function bee_set_abandoned( $user_email, $product_id ) {
		global $wpdb;
		$table_name = $wpdb->prefix . 'bee_abandoned';

		$data = array(
		    'email' => $user_email,
		    'user_id' => 0,
		    'items' => $product_id,
		    'abandoned' => 1,
		);

		$wpdb->insert( $table_name, $data );
	}

	public function bee_show_exit_popup($product_id) {
		$current_url = add_query_arg('abanpopup', 'true', get_permalink());
		wp_redirect($current_url);
		exit;
	}

	// update product in cookie
	public function bee_aban_add_to_cart_update_cookie($cart_item_key, $product_id){

		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			$user_email = $current_user->user_email;
		}
		else {
			if ( isset($_COOKIE['bee_aban_email']) ) {
				$user_email = $_COOKIE['bee_aban_email'];
			}
			else {
				?>
				<style type="text/css">
					#beeabanpopup, #beeabanoverlay {
						display: block;
					}
				</style>
				
				<?php
			}
		}
		if ( !empty($user_email) ) {
			$this->bee_set_abandoned( $user_email, $product_id );
		}

		return;

		
	}

	public function bee_remove_product_abandon($order_id) {
		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			$user_email = $current_user->user_email;
		}
		else {
			if ( isset($_COOKIE['bee_aban_email']) ) {
				$user_email = $_COOKIE['bee_aban_email'];
			}
			else {
				$user_email = '';
			}
		}

		if ( !empty($user_email) ) {
			global $wpdb;
			$table_name = $wpdb->prefix . 'bee_abandoned';
			$current_date = current_time('Y-m-d');
			$sql = $wpdb->prepare(
			    "DELETE FROM $table_name WHERE email = %s AND DATE(last_modified_date) = %s",
			    $user_email,
			    $current_date
			);
			$wpdb->query($sql);
		}
	}
}
