<?php
// No direct file access
!defined('ABSPATH') AND exit;

/**
 * loader class for BeeAban
 */
class BeeAban_Loader
{
	function __construct() {
		$this->bee_abandoned_load_textdomain();
		$this->bee_include_public_files();

		if ( is_admin() ) {
			$this->bee_include_admin_files();
			add_action( 'admin_enqueue_scripts', array( $this, 'bee_aband_enqueue_admin_scripts' ) );
		}
		add_action( 'wp_ajax_bee_aband_send_email', array( $this, 'bee_aband_send_email') );
		add_action( 'bee_aband_sendemail', array( $this, 'bee_send_daily_email') );
	}

	/**
	 * Load Language Localisation.
	 */
	public function bee_abandoned_load_textdomain() {
		load_plugin_textdomain( 'bee_abandoned', false, plugin_basename( dirname( BeeAban_FILE ) ) . '/languages' );
	}

	/**
	 * include required files for admin and hook required for wordpress to triger
	 */
	public function bee_include_admin_files() {
		include_once BeeAban_PATH . 'admin/bee-abandoned-admin-init.php';
    }

    /**
	 * include required files for public
	 */
	public function bee_include_public_files() {
       	include_once BeeAban_PATH . 'includes/bee-abandoned-init.php';
       	$BeeAbandoned = new BeeAbandoned();
    }

    public function bee_aband_enqueue_admin_scripts() {
    	if ( isset($_GET['page']) && ( $_GET['page'] === 'bee-aband-page' || $_GET['page'] === 'bee-plugins' ) ) {
	        wp_enqueue_style( 'bee-aban-admin', BeeAban_URL . '/assets/css/aban-admin.css');
			wp_register_script( 'bee-aban-admin', BeeAban_URL . '/assets/js/aband-admin.js', array('jquery'), time(), true );
			wp_enqueue_script('bee-aban-admin');

			$loc_data = array(
			    'ajax_url' => admin_url('admin-ajax.php'),
			    'nonce'    => wp_create_nonce('beeaband'),
			);

			wp_localize_script('bee-aban-admin', 'beeaband', $loc_data);
	    }
    }

    public function bee_aband_send_email() {
    	// Verify nonce
	    if ( ! isset($_POST['nonce']) || ! wp_verify_nonce($_POST['nonce'], 'beeaband') ) {
	        wp_send_json_error('Invalid nonce');
	    }

		$product_id = $_POST['products'];
		$email = $_POST['email'];

		$this->bee_send_abandoned_notification_email($email);
    }

    public function bee_send_abandoned_notification_email( $to ) {
    	global $woocommerce;
    	$subject = __('Your Cart is Waiting!', 'bee_abandoned');

	    $message = file_get_contents( BeeAban_PATH . '/template/notification-email.php');
	    
	    // Additional headers
	    $headers = array(
	        'Content-Type: text/html; charset=UTF-8',
	        'From: <'. get_option('admin_email') .'>',
	    );

	    // Send the email
	    wp_mail($to, $subject, $message, $headers);

	    wp_send_json_success(array('email_sent' => true ));
    }

    public function bee_send_daily_email() {
    	$table_data = bee_get_abandoned_data();

    	foreach ($table_data as $email => $product_ids) {
    		$this->bee_send_abandoned_notification_email($email);
    	}
    }
}